pub unsafe trait PushKernelArg<T> {
// Required method
fn arg(&mut self, arg: T) -> &mut Self;
}Expand description
Something that can be copied to device memory and turned into a parameter for result::launch_kernel.
See the cuda docs on argument processing.
Safety
This is unsafe you need to ensure that T can be represented in CUDA and also references to it can be properly passed to CUDA.
Most implementations will be required to use #[inline(always)]
to ensure that references are handled properly.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".